Target

Trait Target 

pub trait Target<A, R>
where A: Architecture,
{ // Required method fn run(self, arch: A) -> R; }
A functor that targets a particular architecture, accepting no additional arguments.

Required Methods

fn run(self, arch: A) -> R

Run the operation with the provided Architecture.

Implementors

Source

impl<A, R, F> Target<A, R> for F
where A: Architecture, F: FnOnce() -> R,

Run the closure with code-generated for the specified architecture.

Note that if the body of the closure is not inlined, this will likely have no effect.