Target1

Trait Target1 

pub trait Target1<A, R, T0>
where A: Architecture,
{ // Required method fn run(self, arch: A, x0: T0) -> R; }
A functor that targets a particular architecture, accepting one additional arguments.

Required Methods

fn run(self, arch: A, x0: T0) -> R

Run the operation with the provided Architecture.

Implementors

Source

impl<A, R, T0, F> Target1<A, R, T0> for F
where A: Architecture, F: FnOnce(T0) -> R,

Run the closure with code-generated for the specified architecture.

Note that if the body of the closure is not inlined, this will likely have no effect.