pub trait Target3<A, R, T0, T1, T2>where
A: Architecture,{
// Required method
fn run(self, arch: A, x0: T0, x1: T1, x2: T2) -> R;
}Expand description
A functor that targets a particular architecture, accepting three additional arguments.
Required Methods
Implementors
impl<A, R, T0, T1, T2, F> Target3<A, R, T0, T1, T2> for Fwhere
A: Architecture,
F: FnOnce(T0, T1, T2) -> R,
Run the closure with code-generated for the specified architecture.
Note that if the body of the closure is not inlined, this will likely have no effect.