pub struct Const<const N: usize> {}Expand description
Move a const-generic into the type domain to work around issues with the use and compile-time computation involving const-generic parameters.
See the notes for the various helper traits in traits.rs.