Emulated

Struct Emulated 

pub struct Emulated<T, const N: usize, A = Scalar>(/* private fields */);
An emulated SIMD vector.

The emulated implementation behaves just like an intrinsic, but the APIs are implemented using loops over arrays rather than dispatching to platform specific instructions.

The idea behind this type is that it can be used on architecture where explicit backend support has not been added, or when an architecture does not support a given type/length pair well.

Furthermore, it can be used when developing new back-ends to provide fallback implementations. This allows new back-ends to be developed one piece at a time instead of all at once.

NOTE: The alignment requirements of an emulated vector will be different than the alignment requirements of an actual intrinsic.

Higher level code must not rely on alignments being compatible across architectures!

Implementations

Source

impl<T, const N: usize, A> Emulated<T, N, A>

pub fn from_arch_fn<F>(arch: A, f: F) -> Self
where F: FnMut(usize) -> T,