pub struct LoHi<T> {
pub lo: T,
pub hi: T,
}Expand description
Representation of the low and high halves associated with an implementation of
SplitJoin or crate::ZipUnzip.
Fields
lo: TThe first half of a split entity.
hi: TThe second half of a split entity.
Implementations
Sourceimpl<T> LoHi<T>
impl<T> LoHi<T>
Sourcepub fn zip<U>(self) -> Uwhere
U: ZipUnzip<Halved = T>,
pub fn zip<U>(self) -> Uwhere
U: ZipUnzip<Halved = T>,
Zip-interleave the lo and hi halves into a full-width vector.