Level

Struct Level 

pub struct Level(/* private fields */);
An opaque representation of an Architecture’s capability level.

Level allows comparing the relative capabilities of different architectures without requiring an instance of the architecture type. This is useful for compile-time checks against crate::ARCH where constructing architecture types like x86_64::V3 would require unsafe.

Levels are totally ordered within an ISA family, with greater values indicating more capable instruction sets. Scalar is always the lowest level.

Examples

Checking if the compile-time architecture meets a minimum capability:

#[cfg(target_arch = "x86_64")]
use diskann_wide::{Architecture, arch};

// Check at compile time whether we were built with AVX2+ support.
#[cfg(target_arch = "x86_64")]
let _meets_v3 = arch::Current::level() >= arch::x86_64::V3::level();