pub trait Target2<A, R, T0, T1>where
A: Architecture,{
// Required method
fn run(self, arch: A, x0: T0, x1: T1) -> R;
}Expand description
A functor that targets a particular architecture, accepting two additional arguments.
Required Methods
Implementors
impl<A, R, T0, T1, F> Target2<A, R, T0, T1> for Fwhere
A: Architecture,
F: FnOnce(T0, T1) -> R,
Run the closure with code-generated for the specified architecture.
Note that if the body of the closure is not inlined, this will likely have no effect.