LoHi

Struct LoHi 

pub struct LoHi<T> {
    pub lo: T,
    pub hi: T,
}
Representation of the low and high halves associated with an implementation of SplitJoin.

Fields

lo: T

The first half of a split entity.

hi: T

The second half of a split entity.

Implementations

Source

impl<T> LoHi<T>

pub fn new(lo: T, hi: T) -> Self

Construct a new LoHi from the low and high parts.

pub fn join<U>(self) -> U
where U: SplitJoin<Halved = T>,

Join the lo and hi portions.

pub fn map_with<U, F, R>(self, x: LoHi<U>, f: F) -> LoHi<R>
where F: FnMut(T, U) -> R,

Return a new LoHi with the function f applied to the pairwise members of of self and x.

If it does not panic, f will be invoked exactly twice, first on lo, then on hi.

pub fn map<F, R>(self, f: F) -> LoHi<R>
where F: FnMut(T) -> R,

Return a new LoHi with the function f applied to each member.

If it does not panic, f will be invoked exactly twice, first on lo, then on hi.