SIMDMulAdd

Trait SIMDMulAdd 

pub trait SIMDMulAdd {
    // Required method
    fn mul_add_simd(self, rhs: Self, accumulator: Self) -> Self;
}
Efficiently perform the operation

self * rhs + accumulator

with the following semantics dependent on the associated scalar type.

  • floating point: Perform a fused multiply-add, implementing the operation with only a single rounding instance.

  • integer: Perform the multiplication followed by the accumulation. Both binary operations will be performed using wrap-around arithmetic.

Required Methods

fn mul_add_simd(self, rhs: Self, accumulator: Self) -> Self

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors