pub trait SIMDMulAdd {
// Required method
fn mul_add_simd(self, rhs: Self, accumulator: Self) -> Self;
}Expand description
Efficiently perform the operation
ⓘ
self * rhs + accumulatorwith the following semantics dependent on the associated scalar type.
-
floating point: Perform a fused multiply-add, implementing the operation with only a single rounding instance.
-
integer: Perform the multiplication followed by the accumulation. Both binary operations will be performed using wrap-around arithmetic.
Required Methods
fn mul_add_simd(self, rhs: Self, accumulator: Self) -> Self
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementors
impl SIMDMulAdd for f32x2
impl SIMDMulAdd for f32x4
impl SIMDMulAdd for i8x8
impl SIMDMulAdd for i8x16
impl SIMDMulAdd for i16x8
impl SIMDMulAdd for i32x4
impl SIMDMulAdd for i64x2
impl SIMDMulAdd for u8x8
impl SIMDMulAdd for u8x16
impl SIMDMulAdd for u16x8
impl SIMDMulAdd for u32x4
impl SIMDMulAdd for u64x2
impl<T, const N: usize, A> SIMDMulAdd for Emulated<T, N, A>where
T: ReferenceScalarOps,
MulAdd