pub trait SplitJoin {
type Halved;
// Required methods
fn split(self) -> LoHi<Self::Halved>;
fn join(halves: LoHi<Self::Halved>) -> Self;
}Expand description
Split a type into or join from two halves.
For example, even dimensional fixed size arrays of length N will be split so the first
N / 2 elements are in the low half, and the last N / 2 elements are in the high half.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".